@@ -284,10 +284,13 @@ def test_fuzz_arm(mock, tmp_path, brownie_project):
     )
     assert result.exit_code == 0
 
+
 @patch("fuzzing_cli.fuzz.scribble.ScribbleMixin.instrument_solc_in_place")
 def test_fuzz_arm_no_assert(mock, tmp_path, brownie_project):
     runner = CliRunner()
-    result = runner.invoke(cli, ["arm", "--no-assert", f"{tmp_path}/contracts/sample.sol"])
+    result = runner.invoke(
+        cli, ["arm", "--no-assert", f"{tmp_path}/contracts/sample.sol"]
+    )
 
     mock.assert_called()
     mock.assert_called_with(
@@ -300,7 +303,6 @@ def test_fuzz_arm_no_assert(mock, tmp_path, brownie_project):
     assert result.exit_code == 0
 
 
-
 @patch("fuzzing_cli.fuzz.scribble.ScribbleMixin.disarm_solc_in_place")
 def test_fuzz_disarm(mock, tmp_path, brownie_project):
     runner = CliRunner()
